@@ -22,6 +22,8 @@ package controller
 import (
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-answer/internal/base/middleware"
+	"github.com/apache/incubator-answer/internal/base/pager"
 	"github.com/apache/incubator-answer/internal/service/content"
 	"github.com/apache/incubator-answer/internal/service/event_queue"
 	"github.com/apache/incubator-answer/plugin"
@@ -58,6 +60,7 @@ type TemplateController struct {
 	siteInfoService          siteinfo_common.SiteInfoCommonService
 	eventQueueService        event_queue.EventQueueService
 	userService              *content.UserService
+	questionService          *content.QuestionService
 }
 
 // NewTemplateController new controller
@@ -66,6 +69,7 @@ func NewTemplateController(
 	siteInfoService siteinfo_common.SiteInfoCommonService,
 	eventQueueService event_queue.EventQueueService,
 	userService *content.UserService,
+	questionService *content.QuestionService,
 ) *TemplateController {
 	script, css := GetStyle()
 	return &TemplateController{
@@ -75,6 +79,7 @@ func NewTemplateController(
 		siteInfoService:          siteInfoService,
 		eventQueueService:        eventQueueService,
 		userService:              userService,
+		questionService:          questionService,
 	}
 }
 func GetStyle() (script []string, css string) {
@@ -134,31 +139,40 @@ func (tc *TemplateController) Index(ctx *gin.Context) {
 		OrderCond: "newest",
 	}
 	if handler.BindAndCheck(ctx, req) {
-		tc.Page404(ctx)
 		return
 	}
 
 	var page = req.Page
 
 	data, count, err := tc.templateRenderController.Index(ctx, req)
-	if err != nil {
+	if err != nil || (len(data) == 0 && pager.ValPageOutOfRange(count, page, req.PageSize)) {
 		tc.Page404(ctx)
 		return
 	}
 
+	hotQuestionReq := &schema.QuestionPageReq{
+		Page:      1,
+		PageSize:  6,
+		OrderCond: "hot",
+		InDays:    7,
+	}
+	hotQuestion, _, _ := tc.templateRenderController.Index(ctx, hotQuestionReq)
+
 	siteInfo := tc.SiteInfo(ctx)
 	siteInfo.Canonical = siteInfo.General.SiteUrl
 
 	UrlUseTitle := false
-	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle {
+	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle ||
+		siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitleByShortID {
 		UrlUseTitle = true
 	}
 	siteInfo.Title = ""
 	tc.html(ctx, http.StatusOK, "question.html", siteInfo, gin.H{
-		"data":     data,
-		"useTitle": UrlUseTitle,
-		"page":     templaterender.Paginator(page, req.PageSize, count),
-		"path":     "questions",
+		"data":        data,
+		"useTitle":    UrlUseTitle,
+		"page":        templaterender.Paginator(page, req.PageSize, count),
+		"path":        "questions",
+		"hotQuestion": hotQuestion,
 	})
 }
 
@@ -167,15 +181,23 @@ func (tc *TemplateController) QuestionList(ctx *gin.Context) {
 		OrderCond: "newest",
 	}
 	if handler.BindAndCheck(ctx, req) {
-		tc.Page404(ctx)
 		return
 	}
 	var page = req.Page
 	data, count, err := tc.templateRenderController.Index(ctx, req)
-	if err != nil {
+	if err != nil || (len(data) == 0 && pager.ValPageOutOfRange(count, page, req.PageSize)) {
 		tc.Page404(ctx)
 		return
 	}
+
+	hotQuestionReq := &schema.QuestionPageReq{
+		Page:      1,
+		PageSize:  6,
+		OrderCond: "hot",
+		InDays:    7,
+	}
+	hotQuestion, _, _ := tc.templateRenderController.Index(ctx, hotQuestionReq)
+
 	siteInfo := tc.SiteInfo(ctx)
 	siteInfo.Canonical = fmt.Sprintf("%s/questions", siteInfo.General.SiteUrl)
 	if page > 1 {
@@ -183,18 +205,20 @@ func (tc *TemplateController) QuestionList(ctx *gin.Context) {
 	}
 
 	UrlUseTitle := false
-	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle {
+	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle ||
+		siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitleByShortID {
 		UrlUseTitle = true
 	}
 	siteInfo.Title = fmt.Sprintf("%s - %s", translator.Tr(handler.GetLang(ctx), constant.QuestionsTitleTrKey), siteInfo.General.Name)
 	tc.html(ctx, http.StatusOK, "question.html", siteInfo, gin.H{
-		"data":     data,
-		"useTitle": UrlUseTitle,
-		"page":     templaterender.Paginator(page, req.PageSize, count),
+		"data":        data,
+		"useTitle":    UrlUseTitle,
+		"page":        templaterender.Paginator(page, req.PageSize, count),
+		"hotQuestion": hotQuestion,
 	})
 }
 
-func (tc *TemplateController) QuestionInfoeRdirect(ctx *gin.Context, siteInfo *schema.TemplateSiteInfoResp, correctTitle bool) (jump bool, url string) {
+func (tc *TemplateController) QuestionInfoRedirect(ctx *gin.Context, siteInfo *schema.TemplateSiteInfoResp, correctTitle bool) (jump bool, url string) {
 	questionID := ctx.Param("id")
 	title := ctx.Param("title")
 	answerID := uid.DeShortID(title)
@@ -314,7 +338,7 @@ func (tc *TemplateController) QuestionInfo(ctx *gin.Context) {
 	}
 
 	siteInfo := tc.SiteInfo(ctx)
-	jump, jumpurl := tc.QuestionInfoeRdirect(ctx, siteInfo, correctTitle)
+	jump, jumpurl := tc.QuestionInfoRedirect(ctx, siteInfo, correctTitle)
 	if jump {
 		ctx.Redirect(http.StatusFound, jumpurl)
 		return
@@ -335,7 +359,6 @@ func (tc *TemplateController) QuestionInfo(ctx *gin.Context) {
 	}
 
 	// comments
-
 	objectIDs := []string{uid.DeShortID(id)}
 	for _, answer := range answers {
 		answerID := uid.DeShortID(answer.ID)
@@ -346,6 +369,17 @@ func (tc *TemplateController) QuestionInfo(ctx *gin.Context) {
 		tc.Page404(ctx)
 		return
 	}
+
+	UrlUseTitle := false
+	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle ||
+		siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitleByShortID {
+		UrlUseTitle = true
+	}
+
+	//related question
+	userID := middleware.GetLoginUserIDFromContext(ctx)
+	relatedQuestion, _, _ := tc.questionService.SimilarQuestion(ctx, id, userID)
+
 	siteInfo.Canonical = fmt.Sprintf("%s/questions/%s/%s", siteInfo.General.SiteUrl, id, encodeTitle)
 	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionID || siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDByShortID {
 		siteInfo.Canonical = fmt.Sprintf("%s/questions/%s", siteInfo.General.SiteUrl, id)
@@ -387,7 +421,6 @@ func (tc *TemplateController) QuestionInfo(ctx *gin.Context) {
 			item.Author.URL = fmt.Sprintf("%s/users/%s", siteInfo.General.SiteUrl, answer.UserInfo.Username)
 			answerList = append(answerList, item)
 		}
-
 	}
 	jsonLD.MainEntity.SuggestedAnswer = answerList
 	jsonLDStr, err := json.Marshal(jsonLD)
@@ -403,12 +436,14 @@ func (tc *TemplateController) QuestionInfo(ctx *gin.Context) {
 	siteInfo.Keywords = strings.Replace(strings.Trim(fmt.Sprint(tags), "[]"), " ", ",", -1)
 	siteInfo.Title = fmt.Sprintf("%s - %s", detail.Title, siteInfo.General.Name)
 	tc.html(ctx, http.StatusOK, "question-detail.html", siteInfo, gin.H{
-		"id":       id,
-		"answerid": answerid,
-		"detail":   detail,
-		"answers":  answers,
-		"comments": comments,
-		"noindex":  detail.Show == entity.QuestionHide,
+		"id":              id,
+		"answerid":        answerid,
+		"detail":          detail,
+		"answers":         answers,
+		"comments":        comments,
+		"noindex":         detail.Show == entity.QuestionHide,
+		"useTitle":        UrlUseTitle,
+		"relatedQuestion": relatedQuestion,
 	})
 }
 
@@ -418,8 +453,11 @@ func (tc *TemplateController) TagList(ctx *gin.Context) {
 	if handler.BindAndCheck(ctx, req) {
 		return
 	}
+	if req.PageSize == 0 {
+		req.PageSize = constant.DefaultPageSize
+	}
 	data, err := tc.templateRenderController.TagList(ctx, req)
-	if err != nil {
+	if err != nil || pager.ValPageOutOfRange(data.Count, req.Page, req.PageSize) {
 		tc.Page404(ctx)
 		return
 	}
@@ -466,7 +504,8 @@ func (tc *TemplateController) TagInfo(ctx *gin.Context) {
 	siteInfo.Keywords = tagInfo.DisplayName
 
 	UrlUseTitle := false
-	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle {
+	if siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitle ||
+		siteInfo.SiteSeo.Permalink == constant.PermalinkQuestionIDAndTitleByShortID {
 		UrlUseTitle = true
 	}
 	siteInfo.Title = fmt.Sprintf("'%s' %s - %s", tagInfo.DisplayName, translator.Tr(handler.GetLang(ctx), constant.QuestionsTitleTrKey), siteInfo.General.Name)
