@@ -346,6 +346,7 @@ const (
 	QuestionOrderCondHot        = "hot"
 	QuestionOrderCondScore      = "score"
 	QuestionOrderCondUnanswered = "unanswered"
+	QuestionOrderCondRecommend  = "recommend"
 
 	// HotInDays limit max days of the hottest question
 	HotInDays = 90
@@ -498,3 +499,17 @@ type PersonalCollectionPageReq struct {
 	PageSize int    `validate:"omitempty,min=1" form:"page_size"`
 	UserID   string `json:"-"`
 }
+
+type GetQuestionLinkReq struct {
+	Page       int    `validate:"omitempty,min=1" form:"page"`
+	PageSize   int    `validate:"omitempty,min=1,max=100" form:"page_size"`
+	QuestionID string `validate:"required" form:"question_id"`
+	OrderCond  string `validate:"omitempty,oneof=newest active hot score unanswered recommend" form:"order"`
+	InDays     int    `validate:"omitempty,min=1" form:"in_days"`
+
+	LoginUserID string `json:"-"`
+}
+
+type GetQuestionLinkResp struct {
+	QuestionPageResp
+}
