@@ -22,10 +22,11 @@ package content
 import (
 	"encoding/json"
 	"fmt"
-	"github.com/apache/incubator-answer/internal/service/event_queue"
 	"strings"
 	"time"
 
+	"github.com/apache/incubator-answer/internal/service/event_queue"
+
 	"github.com/apache/incubator-answer/internal/base/constant"
 	"github.com/apache/incubator-answer/internal/base/handler"
 	"github.com/apache/incubator-answer/internal/base/pager"
@@ -173,6 +174,9 @@ func (qs *QuestionService) CloseQuestion(ctx context.Context, req *schema.CloseQ
 	if err != nil {
 		return err
 	}
+	if cf.Key == constant.ReasonADuplicate {
+		qs.questioncommon.AddQuestionLinkForCloseReason(ctx, questionInfo, req.CloseMsg)
+	}
 
 	qs.activityQueueService.Send(ctx, &schema.ActivityMsg{
 		UserID:           req.UserID,
@@ -198,6 +202,7 @@ func (qs *QuestionService) ReopenQuestion(ctx context.Context, req *schema.Reope
 	if err != nil {
 		return err
 	}
+	qs.questioncommon.RemoveQuestionLinkForReopen(ctx, questionInfo)
 	qs.activityQueueService.Send(ctx, &schema.ActivityMsg{
 		UserID:           req.UserID,
 		ObjectID:         questionInfo.ID,
@@ -347,6 +352,16 @@ func (qs *QuestionService) AddQuestion(ctx context.Context, req *schema.Question
 	if err := qs.questionRepo.UpdateQuestionStatus(ctx, question.ID, question.Status); err != nil {
 		return nil, err
 	}
+	if question.Status == entity.QuestionStatusAvailable {
+		question.ParsedText, err = qs.questioncommon.UpdateQuestionLink(ctx, question.ID, "", question.ParsedText, question.OriginalText)
+		if err != nil {
+			return nil, err
+		}
+		err = qs.questionRepo.UpdateQuestion(ctx, question, []string{"parsed_text"})
+		if err != nil {
+			return nil, err
+		}
+	}
 	objectTagData := schema.TagChange{}
 	objectTagData.ObjectID = question.ID
 	objectTagData.Tags = req.Tags
@@ -425,6 +440,14 @@ func (qs *QuestionService) OperationQuestion(ctx context.Context, req *schema.Op
 	switch req.Operation {
 	case schema.QuestionOperationHide:
 		questionInfo.Show = entity.QuestionHide
+		err = qs.questionRepo.RemoveQuestionLink(ctx, &entity.QuestionLink{
+			FromQuestionID: questionInfo.ID,
+		}, &entity.QuestionLink{
+			ToQuestionID: questionInfo.ID,
+		})
+		if err != nil {
+			return
+		}
 		err = qs.tagCommon.HideTagRelListByObjectID(ctx, req.ID)
 		if err != nil {
 			return err
@@ -435,6 +458,14 @@ func (qs *QuestionService) OperationQuestion(ctx context.Context, req *schema.Op
 		}
 	case schema.QuestionOperationShow:
 		questionInfo.Show = entity.QuestionShow
+		err = qs.questionRepo.RecoverQuestionLink(ctx, &entity.QuestionLink{
+			FromQuestionID: questionInfo.ID,
+		}, &entity.QuestionLink{
+			ToQuestionID: questionInfo.ID,
+		})
+		if err != nil {
+			return
+		}
 		err = qs.tagCommon.ShowTagRelListByObjectID(ctx, req.ID)
 		if err != nil {
 			return err
@@ -553,6 +584,14 @@ func (qs *QuestionService) RemoveQuestion(ctx context.Context, req *schema.Remov
 	// if err != nil {
 	// 	 log.Errorf("user DeleteQuestion rank rollback error %s", err.Error())
 	// }
+	err = qs.questionRepo.RemoveQuestionLink(ctx, &entity.QuestionLink{
+		FromQuestionID: questionInfo.ID,
+	}, &entity.QuestionLink{
+		ToQuestionID: questionInfo.ID,
+	})
+	if err != nil {
+		return
+	}
 	qs.activityQueueService.Send(ctx, &schema.ActivityMsg{
 		UserID:           questionInfo.UserID,
 		TriggerUserID:    converter.StringToInt64(req.UserID),
@@ -677,6 +716,14 @@ func (qs *QuestionService) RecoverQuestion(ctx context.Context, req *schema.Ques
 			log.Errorf("update tag's question count failed, %v", err)
 		}
 	}
+	err = qs.questionRepo.RecoverQuestionLink(ctx, &entity.QuestionLink{
+		FromQuestionID: questionInfo.ID,
+	}, &entity.QuestionLink{
+		ToQuestionID: questionInfo.ID,
+	})
+	if err != nil {
+		return
+	}
 
 	qs.activityQueueService.Send(ctx, &schema.ActivityMsg{
 		UserID:           req.UserID,
@@ -921,6 +968,10 @@ func (qs *QuestionService) UpdateQuestion(ctx context.Context, req *schema.Quest
 		//Direct modification
 		revisionDTO.Status = entity.RevisionReviewPassStatus
 		//update question to db
+		question.ParsedText, err = qs.questioncommon.UpdateQuestionLink(ctx, question.ID, "", question.ParsedText, question.OriginalText)
+		if err != nil {
+			return questionInfo, err
+		}
 		saveerr := qs.questionRepo.UpdateQuestion(ctx, question, []string{"title", "original_text", "parsed_text", "updated_at", "post_update_time", "last_edit_user_id"})
 		if saveerr != nil {
 			return questionInfo, saveerr
@@ -930,7 +981,7 @@ func (qs *QuestionService) UpdateQuestion(ctx context.Context, req *schema.Quest
 		objectTagData.Tags = req.Tags
 		objectTagData.UserID = req.UserID
 		tagerr := qs.ChangeTag(ctx, &objectTagData)
-		if err != nil {
+		if tagerr != nil {
 			return questionInfo, tagerr
 		}
 	}
@@ -1573,3 +1624,21 @@ func (qs *QuestionService) SitemapCron(ctx context.Context) {
 	ctx = context.WithValue(ctx, constant.ShortIDFlag, siteSeo.IsShortLink())
 	qs.questioncommon.SitemapCron(ctx)
 }
+
+func (qs *QuestionService) GetQuestionLink(ctx context.Context, req *schema.GetQuestionLinkReq) (
+	questions []*schema.QuestionPageResp, total int64, err error) {
+	if req.OrderCond == schema.QuestionOrderCondHot {
+		req.InDays = schema.HotInDays
+	}
+
+	questionList, total, err := qs.questionRepo.GetQuestionLink(ctx, req.Page, req.PageSize, req.QuestionID, req.OrderCond, req.InDays)
+	if err != nil {
+		return nil, 0, err
+	}
+
+	questions, err = qs.questioncommon.FormatQuestionsPage(ctx, questionList, req.LoginUserID, req.OrderCond)
+	if err != nil {
+		return nil, 0, err
+	}
+	return questions, total, nil
+}
