@@ -54,6 +54,7 @@ type NotificationRepo interface {
 	GetByUserIdObjectIdTypeId(ctx context.Context, userID, objectID string, notificationType int) (*entity.Notification, bool, error)
 	UpdateNotificationContent(ctx context.Context, notification *entity.Notification) (err error)
 	GetById(ctx context.Context, id string) (*entity.Notification, bool, error)
+	CountNotificationByUser(ctx context.Context, cond *entity.Notification) (int64, error)
 }
 
 type NotificationCommon struct {
@@ -103,7 +104,7 @@ func NewNotificationCommon(
 // ObjectInfo.Title
 // ObjectInfo.ObjectID
 // ObjectInfo.ObjectType
-func (ns *NotificationCommon) AddNotification(ctx context.Context, msg *schema.NotificationMsg) error {
+func (ns *NotificationCommon) AddNotification(ctx context.Context, msg *schema.NotificationMsg) (err error) {
 	if msg.Type == schema.NotificationTypeAchievement && plugin.RankAgentEnabled() {
 		return nil
 	}
@@ -119,17 +120,25 @@ func (ns *NotificationCommon) AddNotification(ctx context.Context, msg *schema.N
 		Type:               msg.Type,
 	}
 	var questionID string // just for notify all followers
-	objInfo, err := ns.objectInfoService.GetInfo(ctx, req.ObjectInfo.ObjectID)
-	if err != nil {
-		log.Error(err)
-	} else {
-		req.ObjectInfo.Title = objInfo.Title
-		questionID = objInfo.QuestionID
+	var objInfo *schema.SimpleObjectInfo
+	if msg.ObjectType == constant.BadgeAwardObjectType {
+		req.ObjectInfo.Title = msg.Title
 		objectMap := make(map[string]string)
-		objectMap["question"] = uid.DeShortID(objInfo.QuestionID)
-		objectMap["answer"] = uid.DeShortID(objInfo.AnswerID)
-		objectMap["comment"] = objInfo.CommentID
+		objectMap["badge_id"] = msg.ExtraInfo["badge_id"]
 		req.ObjectInfo.ObjectMap = objectMap
+	} else {
+		objInfo, err = ns.objectInfoService.GetInfo(ctx, req.ObjectInfo.ObjectID)
+		if err != nil {
+			log.Error(err)
+		} else {
+			req.ObjectInfo.Title = objInfo.Title
+			questionID = objInfo.QuestionID
+			objectMap := make(map[string]string)
+			objectMap["question"] = uid.DeShortID(objInfo.QuestionID)
+			objectMap["answer"] = uid.DeShortID(objInfo.AnswerID)
+			objectMap["comment"] = objInfo.CommentID
+			req.ObjectInfo.ObjectMap = objectMap
+		}
 	}
 
 	if msg.Type == schema.NotificationTypeAchievement {
@@ -188,10 +197,13 @@ func (ns *NotificationCommon) AddNotification(ctx context.Context, msg *schema.N
 	if err != nil {
 		return fmt.Errorf("add notification error: %w", err)
 	}
-	err = ns.addRedDot(ctx, info.UserID, info.Type)
+	err = ns.addRedDot(ctx, info.UserID, msg.Type)
 	if err != nil {
 		log.Error("addRedDot Error", err.Error())
 	}
+	if req.ObjectInfo.ObjectType == constant.BadgeAwardObjectType {
+		err = ns.AddBadgeAwardAlertCache(ctx, info.UserID, info.ID, req.ObjectInfo.ObjectMap["badge_id"])
+	}
 
 	go ns.SendNotificationToAllFollower(ctx, msg, questionID)
 
@@ -201,19 +213,115 @@ func (ns *NotificationCommon) AddNotification(ctx context.Context, msg *schema.N
 	return nil
 }
 
-func (ns *NotificationCommon) addRedDot(ctx context.Context, userID string, botType int) error {
-	key := fmt.Sprintf("answer_RedDot_%d_%s", botType, userID)
-	err := ns.data.Cache.SetInt64(ctx, key, 1, 30*24*time.Hour) //Expiration time is one month.
+func (ns *NotificationCommon) addRedDot(ctx context.Context, userID string, noticeType int) error {
+	var key string
+	if noticeType == schema.NotificationTypeInbox {
+		key = fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeInbox, userID)
+	} else {
+		key = fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeAchievement, userID)
+	}
+	_, exist, err := ns.data.Cache.GetInt64(ctx, key)
+	if err != nil {
+		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+	}
+	if exist {
+		if _, err := ns.data.Cache.Increase(ctx, key, 1); err != nil {
+			return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+		}
+		return nil
+	}
+	err = ns.data.Cache.SetInt64(ctx, key, 1, constant.RedDotCacheTime)
 	if err != nil {
 		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
 	}
 	return nil
 }
 
+func (ns *NotificationCommon) DecreaseRedDot(ctx context.Context, userID string, notificationType int) error {
+	var key string
+	if notificationType == schema.NotificationTypeInbox {
+		key = fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeInbox, userID)
+	} else {
+		key = fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeAchievement, userID)
+	}
+	_, exist, err := ns.data.Cache.GetInt64(ctx, key)
+	if err != nil {
+		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+	}
+	if !exist {
+		return nil
+	}
+	res, err := ns.data.Cache.Decrease(ctx, key, 1)
+	if err != nil {
+		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+	}
+	if res <= 0 {
+		return ns.DeleteRedDot(ctx, userID, notificationType)
+	}
+	return nil
+}
+
+func (ns *NotificationCommon) DeleteRedDot(ctx context.Context, userID string, notificationType int) error {
+	var key string
+	if notificationType == schema.NotificationTypeInbox {
+		key = fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeInbox, userID)
+	} else {
+		key = fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeAchievement, userID)
+	}
+	err := ns.data.Cache.Del(ctx, key)
+	if err != nil {
+		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+	}
+	return nil
+}
+
+// AddBadgeAwardAlertCache add badge award alert cache
+func (ns *NotificationCommon) AddBadgeAwardAlertCache(ctx context.Context, userID, notificationID, badgeID string) (err error) {
+	key := fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeBadgeAchievement, userID)
+	cacheData, exist, err := ns.data.Cache.GetString(ctx, key)
+	if err != nil {
+		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+	}
+	if !exist {
+		c := schema.NewRedDotBadgeAwardCache()
+		c.AddBadgeAward(&schema.RedDotBadgeAward{
+			NotificationID: notificationID,
+			BadgeID:        badgeID,
+		})
+		return ns.data.Cache.SetString(ctx, key, c.ToJSON(), constant.RedDotCacheTime)
+	}
+	c := schema.NewRedDotBadgeAwardCache()
+	c.FromJSON(cacheData)
+	c.AddBadgeAward(&schema.RedDotBadgeAward{
+		NotificationID: notificationID,
+		BadgeID:        badgeID,
+	})
+	return ns.data.Cache.SetString(ctx, key, c.ToJSON(), constant.RedDotCacheTime)
+}
+
+// RemoveBadgeAwardAlertCache remove badge award alert cache
+func (ns *NotificationCommon) RemoveBadgeAwardAlertCache(ctx context.Context, userID, notificationID string) (err error) {
+	key := fmt.Sprintf(constant.RedDotCacheKey, constant.NotificationTypeBadgeAchievement, userID)
+	cacheData, exist, err := ns.data.Cache.GetString(ctx, key)
+	if err != nil {
+		return errors.InternalServer(reason.UnknownError).WithError(err).WithStack()
+	}
+	if !exist {
+		return nil
+	}
+	c := schema.NewRedDotBadgeAwardCache()
+	c.FromJSON(cacheData)
+	c.RemoveBadgeAward(notificationID)
+	if len(c.BadgeAwardList) == 0 {
+		return ns.data.Cache.Del(ctx, key)
+	}
+	return ns.data.Cache.SetString(ctx, key, c.ToJSON(), constant.RedDotCacheTime)
+}
+
 // SendNotificationToAllFollower send notification to all followers
 func (ns *NotificationCommon) SendNotificationToAllFollower(ctx context.Context, msg *schema.NotificationMsg,
 	questionID string) {
-	if msg.NoNeedPushAllFollow {
+	if msg.NoNeedPushAllFollow || len(questionID) == 0 {
 		return
 	}
 	if msg.NotificationAction != constant.NotificationUpdateQuestion &&
