@@ -22,7 +22,10 @@ package questioncommon
 import (
 	"context"
 	"encoding/json"
+	"fmt"
+	"github.com/apache/incubator-answer/internal/service/siteinfo_common"
 	"math"
+	"strings"
 	"time"
 
 	"github.com/apache/incubator-answer/internal/base/constant"
@@ -75,6 +78,11 @@ type QuestionRepo interface {
 	SitemapQuestions(ctx context.Context, page, pageSize int) (questionIDList []*schema.SiteMapQuestionInfo, err error)
 	RemoveAllUserQuestion(ctx context.Context, userID string) (err error)
 	UpdateSearch(ctx context.Context, questionID string) (err error)
+	LinkQuestion(ctx context.Context, link ...*entity.QuestionLink) (err error)
+	RemoveQuestionLink(ctx context.Context, link ...*entity.QuestionLink) (err error)
+	RecoverQuestionLink(ctx context.Context, link ...*entity.QuestionLink) (err error)
+	UpdateQuestionLinkStatus(ctx context.Context, status int, links ...*entity.QuestionLink) (err error)
+	GetQuestionLink(ctx context.Context, page, pageSize int, questionID string, orderCond string, inDays int) (questions []*entity.Question, total int64, err error)
 }
 
 // QuestionCommon user service
@@ -91,6 +99,7 @@ type QuestionCommon struct {
 	configService        *config.ConfigService
 	activityQueueService activity_queue.ActivityQueueService
 	revisionRepo         revision.RevisionRepo
+	siteInfoService      siteinfo_common.SiteInfoCommonService
 	data                 *data.Data
 }
 
@@ -106,6 +115,7 @@ func NewQuestionCommon(questionRepo QuestionRepo,
 	configService *config.ConfigService,
 	activityQueueService activity_queue.ActivityQueueService,
 	revisionRepo revision.RevisionRepo,
+	siteInfoService siteinfo_common.SiteInfoCommonService,
 	data *data.Data,
 ) *QuestionCommon {
 	return &QuestionCommon{
@@ -121,6 +131,7 @@ func NewQuestionCommon(questionRepo QuestionRepo,
 		configService:        configService,
 		activityQueueService: activityQueueService,
 		revisionRepo:         revisionRepo,
+		siteInfoService:      siteInfoService,
 		data:                 data,
 	}
 }
@@ -682,3 +693,181 @@ func (qs *QuestionCommon) ShowFormatWithTag(ctx context.Context, data *entity.Qu
 	info.Tags = Tags
 	return info
 }
+
+func (qs *QuestionCommon) UpdateQuestionLink(ctx context.Context, questionID, answerID, parsedText, originalText string) (string, error) {
+	err := qs.questionRepo.RemoveQuestionLink(ctx, &entity.QuestionLink{
+		FromQuestionID: uid.DeShortID(questionID),
+		FromAnswerID:   uid.DeShortID(answerID),
+	})
+	if err != nil {
+		return parsedText, err
+	}
+
+	links := checker.GetQuestionLink(originalText)
+	if len(links) == 0 {
+		return parsedText, nil
+	}
+
+	// get answer ids and question ids
+	answerIDs := make([]string, 0, len(links))
+	questionIDs := make([]string, 0, len(links))
+	for _, link := range links {
+		if link.AnswerID != "" {
+			answerIDs = append(answerIDs, link.AnswerID)
+		}
+		if link.QuestionID != "" {
+			questionIDs = append(questionIDs, link.QuestionID)
+		}
+	}
+
+	// get answer info and build cache
+	answerInfoList, err := qs.answerRepo.GetByIDs(ctx, answerIDs...)
+	if err != nil {
+		return parsedText, err
+	}
+	answerCache := make(map[string]string, len(answerInfoList))
+	for _, ans := range answerInfoList {
+		answerID := uid.DeShortID(ans.ID)
+		questionID := ans.QuestionID
+		answerCache[answerID] = questionID
+	}
+
+	// get question info and build cache
+	questionInfoList, err := qs.questionRepo.FindByID(ctx, questionIDs)
+	if err != nil {
+		return parsedText, err
+	}
+	questionCache := make(map[string]struct{}, len(questionInfoList))
+	for _, q := range questionInfoList {
+		questionID := uid.DeShortID(q.ID)
+		questionCache[questionID] = struct{}{}
+	}
+
+	// process links and generate new QuestionLink
+	validLinks := make([]*entity.QuestionLink, 0, len(links))
+	for _, link := range links {
+		linkQuestionID := uid.DeShortID(link.QuestionID)
+		linkAnswerID := uid.DeShortID(link.AnswerID)
+		// validate question id
+		if _, exists := questionCache[linkQuestionID]; linkQuestionID != "0" && !exists {
+			continue
+		}
+
+		// validate answer id
+		if linkAnswerID != "0" {
+			linkedQuestionID, exists := answerCache[linkAnswerID]
+			if !exists {
+				continue
+			}
+			// if question id is empty, get it from answer cache
+			if link.QuestionID == "" {
+				link.QuestionID = linkedQuestionID
+			}
+		}
+
+		// build new link
+		newLink := &entity.QuestionLink{
+			FromQuestionID: uid.DeShortID(questionID),
+			FromAnswerID:   uid.DeShortID(answerID),
+			ToQuestionID:   uid.DeShortID(link.QuestionID),
+			ToAnswerID:     uid.DeShortID(link.AnswerID),
+		}
+		// replace link in parsed text
+		if link.QuestionID != "" {
+			htmlLink := fmt.Sprintf("<a href=\"/questions/%s\">#%s</a>", link.QuestionID, link.QuestionID)
+			parsedText = strings.ReplaceAll(parsedText, "#"+link.QuestionID, htmlLink)
+		}
+		if link.AnswerID != "" {
+			linkedQuestionID := answerCache[linkAnswerID]
+			htmlLink := fmt.Sprintf("<a href=\"/questions/%s/%s\">#%s</a>", linkedQuestionID, link.AnswerID, link.AnswerID)
+			parsedText = strings.ReplaceAll(parsedText, "#"+link.AnswerID, htmlLink)
+			newLink.ToQuestionID = uid.DeShortID(linkedQuestionID)
+		}
+		// avoid link to self
+		if newLink.FromQuestionID != newLink.ToQuestionID {
+			validLinks = append(validLinks, newLink)
+		}
+	}
+
+	// add new links to repo
+	if len(validLinks) > 0 {
+		err = qs.questionRepo.LinkQuestion(ctx, validLinks...)
+		if err != nil {
+			return parsedText, err
+		}
+	}
+
+	return parsedText, nil
+}
+
+// AddQuestionLinkForCloseReason When the reason about close question is a question link, add the link to the question
+func (qs *QuestionCommon) AddQuestionLinkForCloseReason(ctx context.Context,
+	questionInfo *entity.Question, closeMsg string) {
+	questionID := qs.tryToGetQuestionIDFromMsg(ctx, closeMsg)
+	if len(questionID) == 0 {
+		return
+	}
+
+	linkedQuestion, exist, err := qs.questionRepo.GetQuestion(ctx, questionID)
+	if err != nil {
+		log.Errorf("get question error %s", err)
+		return
+	}
+	if !exist {
+		return
+	}
+	err = qs.questionRepo.LinkQuestion(ctx, &entity.QuestionLink{
+		FromQuestionID: questionInfo.ID,
+		ToQuestionID:   linkedQuestion.ID,
+		Status:         entity.QuestionLinkStatusAvailable,
+	})
+	if err != nil {
+		log.Errorf("link question error %s", err)
+	}
+}
+
+func (qs *QuestionCommon) RemoveQuestionLinkForReopen(ctx context.Context, questionInfo *entity.Question) {
+	questionInfo.ID = uid.DeShortID(questionInfo.ID)
+	metaInfo, err := qs.metaCommonService.GetMetaByObjectIdAndKey(ctx, questionInfo.ID, entity.QuestionCloseReasonKey)
+	if err != nil {
+		return
+	}
+
+	closeMsgMeta := &schema.CloseQuestionMeta{}
+	_ = json.Unmarshal([]byte(metaInfo.Value), closeMsgMeta)
+
+	linkedQuestionID := qs.tryToGetQuestionIDFromMsg(ctx, closeMsgMeta.CloseMsg)
+	if len(linkedQuestionID) == 0 {
+		return
+	}
+	err = qs.questionRepo.RemoveQuestionLink(ctx, &entity.QuestionLink{
+		FromQuestionID: questionInfo.ID,
+		ToQuestionID:   linkedQuestionID,
+	})
+	if err != nil {
+		log.Errorf("remove question link error %s", err)
+	}
+}
+
+func (qs *QuestionCommon) tryToGetQuestionIDFromMsg(ctx context.Context, closeMsg string) (questionID string) {
+	siteGeneral, err := qs.siteInfoService.GetSiteGeneral(ctx)
+	if err != nil {
+		log.Errorf("get site general error %s", err)
+		return
+	}
+	if !strings.HasPrefix(closeMsg, siteGeneral.SiteUrl) {
+		return
+	}
+	// get question id from url
+	// the url may like: https://xxx.com/questions/D1401/xxx
+	// the D1401 is question id
+	questionID = strings.TrimPrefix(closeMsg, siteGeneral.SiteUrl)
+	questionID = strings.TrimPrefix(questionID, "/questions/")
+	t := strings.Split(questionID, "/")
+	if len(t) < 1 {
+		return ""
+	}
+	questionID = t[0]
+	questionID = uid.DeShortID(questionID)
+	return questionID
+}
