@@ -46,7 +46,7 @@ export const QUESTION_ORDER_KEYS: Type.QuestionOrderBy[] = [
   'recommend',
 ];
 interface Props {
-  source: 'questions' | 'tag';
+  source: 'questions' | 'tag' | 'linked';
   order?: Type.QuestionOrderBy;
   data;
   orderList?: Type.QuestionOrderBy[];
@@ -118,9 +118,15 @@ const QuestionList: FC<Props> = ({
                     />
                     •
                     <FormatTime
-                      time={li.operated_at}
+                      time={
+                        curOrder === 'active' ? li.operated_at : li.created_at
+                      }
                       className="text-secondary ms-1 flex-shrink-0"
-                      preFix={t(li.operation_type)}
+                      preFix={
+                        curOrder === 'active'
+                          ? t(li.operation_type)
+                          : t('asked')
+                      }
                     />
                   </div>
                   <Counts
